response_time

Function response_time 

pub fn response_time(conn: &Conn, _color: bool) -> ResponseTimeOutput
Available on crate feature client only.
Formatter for the wall-clock duration between when ClientLogger first ran and when the log line is rendered.

If no ClientLogger preceded this in the handler chain, prints -.